#At file:///MySQL/REPO/V55/itch-5.5/ based on revid:joerg@stripped
3100 Joerg Bruehe 2011-01-25 [merge]
Get a new change of the 42969 bug, for a test build.
modified:
support-files/mysql.spec.sh
=== modified file 'support-files/mysql.spec.sh'
--- a/support-files/mysql.spec.sh 2011-01-24 12:34:07 +0000
+++ b/support-files/mysql.spec.sh 2011-01-25 15:30:09 +0000
@@ -506,9 +506,9 @@ touch $RBR%{_sysconfdir}/my.cnf
install -m 600 $MBD/%{src_dir}/support-files/RHEL4-SElinux/mysql.{fc,te} \
$RBR%{_datadir}/mysql/SELinux/RHEL4
-# Install INFO_* (info about source and binaries) files in datadir
-install -m 644 $MBD/%{src_dir}/INFO_SRC $RBR%{_datadir}/mysql
-install -m 644 $MBD/release/INFO_BIN $RBR%{_datadir}/mysql
+# Install INFO_* (info about source and binaries) files in infodir
+install -m 644 $MBD/%{src_dir}/INFO_SRC $RBR%{_infodir}
+install -m 644 $MBD/release/INFO_BIN $RBR%{_infodir}
%if %{WITH_TCMALLOC}
# Even though this is a shared library, put it under /usr/lib*/mysql, so it
@@ -915,6 +915,8 @@ echo "====="
%doc release/support-files/my-*.cnf
%doc %attr(644, root, root) %{_infodir}/mysql.info*
+%doc %attr(644, root, root) %{_infodir}/INFO_SRC
+%doc %attr(644, root, root) %{_infodir}/INFO_BIN
%doc %attr(644, root, man) %{_mandir}/man1/innochecksum.1*
%doc %attr(644, root, man) %{_mandir}/man1/my_print_defaults.1*
@@ -1089,10 +1091,10 @@ echo "====="
# merging BK trees)
##############################################################################
%changelog
-* Mon Jan 24 2011 Joerg Bruehe <joerg.bruehe@stripped>
+* Tue Jan 25 2011 Joerg Bruehe <joerg.bruehe@stripped>
-- Install the new "manifest" files: "INFO_SRC" and "INFO_BIN"
- in the data directory, "/usr/share/mysql/".
+- Install the new "manifest" files:
+ "INFO_SRC" and "INFO_BIN" in the "info" directory.
* Tue Nov 23 2010 Jonathan Perkin <jonathan.perkin@stripped>
No bundle (reason: revision is a merge (you can force generation of a bundle with env var BZR_FORCE_BUNDLE=1)).
| Thread |
|---|
| • bzr commit into mysql-5.5-bugteam branch (joerg:3100) | Joerg Bruehe | 25 Jan |